#
# spec file for package simtrace2
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2018-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1
Name:           simtrace2
Version:        0.8.0
Release:        1.9
Summary:        Osmocom SIMtrace host utility
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities
URL:            https://osmocom.org/projects/simtrace2/wiki
Source:         %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libosmocore) >= 1.4.0
BuildRequires:  pkgconfig(libosmosim) >= 1.4.0
BuildRequires:  pkgconfig(libosmousb) >= 1.4.0
BuildRequires:  pkgconfig(libpcsclite)
BuildRequires:  pkgconfig(libusb-1.0)

%description
Osmocom SIMtrace 2 is a software and hardware system for passively
tracing SIM-ME communication between the SIM card and the mobile phone,
and remote SIM operation.

This package contains SIMtrace 2 host utility.

%package -n libosmo-simtrace2-%{sover}
Summary:        Driver functions for Osmocom SIMtrace2 and compatible firmware
Group:          System/Libraries

%description -n libosmo-simtrace2-%{sover}
This library contains core "driver" functionality to interface with the
Osmocom SIMtrace2 (and compatible) USB device firmware.  It enables
applications to implement SIM card / smart card tracing as well as
SIM / smart card emulation functions.

%package -n libosmo-simtrace2-devel
Summary:        Development files for the Osmocom SIMtrace2 library
Group:          Development/Libraries/C and C++
Requires:       libosmo-simtrace2-%{sover} = %{version}

%description -n libosmo-simtrace2-devel
Osmocom SIMtrace2 (and compatible) USB device firmware.  It enables
applications to implement SIM card / smart card tracing as well as
SIM / smart card emulation functions.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-simtrace2.

%prep
%setup -q

%build
echo "%{version}" >.tarball-version
cd host
autoreconf -fiv
%configure --disable-static
%make_build

%install
%make_install -C host
install -Dm0644 host/contrib/99-simtrace2.rules %{buildroot}/%{_udevrulesdir}/99-simtrace2.rules
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libosmo-simtrace2-%{sover} -p /sbin/ldconfig
%postun -n libosmo-simtrace2-%{sover} -p /sbin/ldconfig

%files
%license host/COPYING
%doc README.md
%{_bindir}/simtrace2-cardem-pcsc
%{_bindir}/simtrace2-list
%{_bindir}/simtrace2-sniff
%{_bindir}/simtrace2-tool
%{_udevrulesdir}/99-simtrace2.rules

%files -n libosmo-simtrace2-%{sover}
%{_libdir}/libosmo-simtrace2.so.%{sover}*

%files -n libosmo-simtrace2-devel
%dir %{_includedir}/osmocom/
%dir %{_includedir}/osmocom/simtrace2/
%{_includedir}/osmocom/simtrace2/*.h
%{_libdir}/libosmo-simtrace2.so
%{_libdir}/pkgconfig/libosmo-simtrace2.pc

%changelog
* Thu Dec  9 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.0
  * Introduce simtrace2-tool
  * 99-simtrace2.rules: Add OCTSIMTEST
  * add ISO 7816-3 library to remsim project
  * add library providing ISO 7816-3 utilities
  * rename simtrace2-remsim to simtrace2-cardem-pcsc
  * remove usb2udp
  * remsim: adding cli argument to set the atr
  * Introduce support for asynchronous USB transmission
  * simtrace2_api: Add osmo_st2_cardem_request_config()
* Fri Jan 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.1
  * Add missing license files
  * No functional changes
- Add license file to the %%license section
* Sun Jan 12 2020 Martin Hauke <mardnh@gmx.de>
- Initial package for simtrace2
